==> rustc_1.73.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.73.0-src/tests/ui/rfcs/rfc-2294-if-let-guard/feature-gate.rs <==
// gate-test-if_let_guard

use std::ops::Range;

fn _if_let_guard() {
    match () {
        () if let 0 = 1 => {}
        //~^ ERROR `if let` guards are experimental

        () if (let 0 = 1) => {}
        //~^ ERROR `let` expressions in this position are unstable
        //~| ERROR expected expression, found `let` statement
        //~| ERROR `let` expressions are not supported here

        () if (((let 0 = 1))) => {}
        //~^ ERROR `let` expressions in this position are unstable
        //~| ERROR expected expression, found `let` statement
        //~| ERROR `let` expressions are not supported here

        () if true && let 0 = 1 => {}
        //~^ ERROR `if let` guards are experimental
        //~| ERROR `let` expressions in this position are unstable

        () if let 0 = 1 && true => {}
        //~^ ERROR `if let` guards are experimental
        //~| ERROR `let` expressions in this position are unstable

        () if (let 0 = 1) && true => {}
        //~^ ERROR `let` expressions in this position are unstable
        //~| ERROR expected expression, found `let` statement
        //~| ERROR `let` expressions are not supported here

        () if true && (let 0 = 1) => {}
        //~^ ERROR `let` expressions in this position are unstable
        //~| ERROR expected expression, found `let` statement
        //~| ERROR `let` expressions are not supported here

        () if (let 0 = 1) && (let 0 = 1) => {}
        //~^ ERROR `let` expressions in this position are unstable
        //~| ERROR `let` expressions in this position are unstable
        //~| ERROR expected expression, found `let` statement
        //~| ERROR expected expression, found `let` statement
        //~| ERROR `let` expressions are not supported here
        //~| ERROR `let` expressions are not supported here

        () if let 0 = 1 && let 1 = 2 && (let 2 = 3 && let 3 = 4 && let 4 = 5) => {}
        //~^ ERROR `if let` guards are experimental
        //~| ERROR `let` expressions in this position are unstable
        //~| ERROR `let` expressions in this position are unstable
        //~| ERROR `let` expressions in this position are unstable
        //~| ERROR `let` expressions in this position are unstable
        //~| ERROR `let` expressions in this position are unstable
        //~| ERROR expected expression, found `let` statement
        //~| ERROR expected expression, found `let` statement
        //~| ERROR expected expression, found `let` statement
        //~| ERROR `let` expressions are not supported here
        //~| ERROR `let` expressions are not supported here
        //~| ERROR `let` expressions are not supported here


        () if let Range { start: _, end: _ } = (true..true) && false => {}
        //~^ ERROR `if let` guards are experimental
        //~| ERROR `let` expressions in this position are unstable

        _ => {}
    }
}

fn _macros() {
    macro_rules! use_expr {
        ($e:expr) => {
            match () {
                () if $e => {}
                _ => {}
            }
        }
    }
    use_expr!((let 0 = 1 && 0 == 0));
    //~^ ERROR `let` expressions in this position are unstable
    //~| ERROR expected expression, found `let` statement
    //~| ERROR `let` expressions are not supported here
    use_expr!((let 0 = 1));
    //~^ ERROR `let` expressions in this position are unstable
    //~| ERROR expected expression, found `let` statement
    //~| ERROR `let` expressions are not supported here
    match () {
        #[cfg(FALSE)]
        () if let 0 = 1 => {}
        //~^ ERROR `if let` guards are experimental
        _ => {}
    }
    use_expr!(let 0 = 1);
    //~^ ERROR no rules expected the token `let`
}

fn main() {}

==> rustc-1.89_1.89.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.89.0-src/tests/ui/rfcs/rfc-2294-if-let-guard/feature-gate.rs <==
// gate-test-if_let_guard

use std::ops::Range;

fn _if_let_guard() {
    match () {
        () if let 0 = 1 => {}
        //~^ ERROR `if let` guards are experimental

        () if (let 0 = 1) => {}
        //~^ ERROR expected expression, found `let` statement

        () if (((let 0 = 1))) => {}
        //~^ ERROR expected expression, found `let` statement

        () if true && let 0 = 1 => {}
        //~^ ERROR `if let` guards are experimental

        () if let 0 = 1 && true => {}
        //~^ ERROR `if let` guards are experimental

        () if (let 0 = 1) && true => {}
        //~^ ERROR expected expression, found `let` statement

        () if true && (let 0 = 1) => {}
        //~^ ERROR expected expression, found `let` statement

        () if (let 0 = 1) && (let 0 = 1) => {}
        //~^ ERROR expected expression, found `let` statement
        //~| ERROR expected expression, found `let` statement

        () if let 0 = 1 && let 1 = 2 && (let 2 = 3 && let 3 = 4 && let 4 = 5) => {}
        //~^ ERROR `if let` guards are experimental
        //~| ERROR expected expression, found `let` statement
        //~| ERROR expected expression, found `let` statement
        //~| ERROR expected expression, found `let` statement


        () if let Range { start: _, end: _ } = (true..true) && false => {}
        //~^ ERROR `if let` guards are experimental

        _ => {}
    }
}

fn _macros() {
    macro_rules! use_expr {
        ($e:expr) => {
            match () {
                () if $e => {}
                _ => {}
            }
        }
    }
    use_expr!((let 0 = 1 && 0 == 0));
    //~^ ERROR expected expression, found `let` statement
    //~| ERROR expected expression, found `let` statement
    use_expr!((let 0 = 1));
    //~^ ERROR expected expression, found `let` statement
    //~| ERROR expected expression, found `let` statement
    match () {
        #[cfg(false)]
        () if let 0 = 1 => {}
        //~^ ERROR `if let` guards are experimental
        _ => {}
    }
    use_expr!(let 0 = 1);
    //~^ ERROR no rules expected keyword `let`
}

fn main() {}
